function buffer = I2CEncodeBitstream(address,write,bytes)
    assert(isa(write,'logical'));
    assert(isa(address,'uint8') && address < 2^7);
    assert(isa(bytes,'uint8'));
    
    % column 1 is SDA, column 2 is SCL
    startbit = [true true; false true];
    stopbit  = [NaN false; false false; false true; true true];

    firstbyte = bitset(bitshift(address,1),1,~write);
    bytes = [firstbyte bytes(:)'];

    buffer = arrayfun(@(byte)encodeByte(byte),bytes,'UniformOutput',false);
    buffer = vertcat(startbit, buffer{:}, stopbit);

    % replace NaNs
    for i = 1:size(buffer,1)
        if isnan(buffer(i,1))
            buffer(i,1) = buffer(i-1,1);
        end
    end
end


function buffer = encodeByte(byte)
	assert(isa(byte,'uint8'));
	
	% column 1 is SDA, column 2 is SCL
	buffer = zeros(9*3,2);
	
    for i = 1:8
        buffer((i-1)*3+1,:) = [NaN false];
		buffer((i-1)*3+2,:) = [bitget(byte,9-i) false];
		buffer((i-1)*3+3,:) = [bitget(byte,9-i) true];
    end
    
    % ACK bit
    buffer((9-1)*3+1,:) = [NaN false];
	buffer((9-1)*3+2,:) = [false false];
	buffer((9-1)*3+3,:) = [false true];
end