% use a DAQ board to emulate an I2C master
% since the DAQ board actively controls SDA and SCL
% no pull up resistors to VDD are required
devName = 'Dev1';
sdaLine = 'port0/line0';
sclLine = 'port0/line1';
outputRate = 1e6; % [Hz]

hI2CTask = most.util.safeCreateTask('I2CTask');
hI2CTask.createDOChan(devName,sdaLine,'I2C SDA','DAQmx_Val_ChanPerLine');
hI2CTask.createDOChan(devName,sclLine,'I2C SCL','DAQmx_Val_ChanPerLine');
hI2CTask.cfgSampClkTiming(outputRate, 'DAQmx_Val_FiniteSamps', 10); %sampsPerChanToAcquire is reconfigured for every write operation

I2CAddress = uint8(0);
packetData = uint8([1 2 3 4 5 6 7 8 9 10]);
bitstream = I2CEncodeBitstream(I2CAddress,true,packetData);

% since we don't know the state of the bus at this point start the
% transmission with an end of transmission sequence (change SDA up while SCL is high)
% this resets FPGA I2C engine
           % SDA,   SCL
resetBit = [ false, false;...
             false, true ;...
             true,  true ];
bitstream = vertcat(resetBit,bitstream);

hI2CTask.abort();
hI2CTask.set('sampQuantSampPerChan',size(bitstream,1));
hI2CTask.set('bufOutputBufSize',size(bitstream,1));
hI2CTask.writeDigitalData(bitstream,1,false);
hI2CTask.start();
hI2CTask.waitUntilTaskDone(1); % this is a blocking call
hI2CTask.abort();
hI2CTask.control('DAQmx_Val_Task_Unreserve');